@@ -22,8 +22,8 @@ import importlib
 sys.path.append(os.getcwd())
 
 # Globals
-DATA_DIR = f'{os.getcwd()}/tests'
-
+TEST_DIR = f'{os.getcwd()}/tests'
+DATA_DIR = f'{os.getcwd()}/data'
 
 def get_task_names():
     tasks = [x.replace('.py', '') for x in os.listdir(f'{os.getcwd()}/imports') if x.endswith('.py')]
@@ -35,8 +35,8 @@ def get_task_names():
 
 def gather_test_dirs(task):
     tests = []
-    if os.path.exists(os.path.join(DATA_DIR, task)):
-        tests = [d for d in os.listdir(os.path.join(DATA_DIR, task)) if re.findall(r'test_.+', d)]
+    if os.path.exists(os.path.join(TEST_DIR, task)):
+        tests = [d for d in os.listdir(os.path.join(TEST_DIR, task)) if re.findall(r'test_.+', d)]
     return tests
 
 
@@ -69,7 +69,7 @@ def get_test_config(task, test):
     """
     Get the config for the test
     """
-    file_path = f'{DATA_DIR}/{task}/{test}/config.json'
+    file_path = f'{TEST_DIR}/{task}/{test}/config.json'
     config = {}
     if os.path.exists(file_path):
         config = json.load(open(file_path, 'r'))
@@ -80,7 +80,7 @@ def get_mock_data(task, test):
     """
     Get the mock data for the test
     """
-    file_path = f'{DATA_DIR}/{task}/{test}/mocks.json'
+    file_path = f'{TEST_DIR}/{task}/{test}/mocks.json'
     mocks = []
     if os.path.exists(file_path):
         mocks = json.load(open(file_path, 'r'))
@@ -149,14 +149,14 @@ class TestStandardRest:
     @mock_session
     def cls(self, task, test):
         """Instantiate SwMain for general tests"""
-        inputs = json.load(open(f'{DATA_DIR}/{task}/{test}/inputs.json')) if task != 'asset' else {}
+        inputs = json.load(open(f'{TEST_DIR}/{task}/{test}/inputs.json')) if task != 'asset' else {}
         return sw_main(task, inputs, None)
 
     def test_kwargs(self, *args, **kwargs):
         """
         This will test the payload schema json, params, data, files, etc. As utils passes it.
         """
-        schema = json.loads(open(f'{DATA_DIR}/{self.task}/schemas/kwargs.json').read())
+        schema = json.loads(open(f'{TEST_DIR}/{self.task}/schemas/kwargs.json').read())
         validate(
             instance=self.ctx.get_kwargs(),
             schema=schema
@@ -168,12 +168,12 @@ class TestStandardRest:
         """
         # check if local header schema, this overrides global.
         try:
-            schema = json.loads(open(f'{DATA_DIR}/{self.task}/schemas/headers.json').read())
+            schema = json.loads(open(f'{TEST_DIR}/{self.task}/schemas/headers.json').read())
         except:
             schema = False
         if not schema:
             # check if global schema
-            schema = json.loads(open(f'{DATA_DIR}/headers.json').read())
+            schema = json.loads(open(f'{TEST_DIR}/headers.json').read())
             if not schema:
                 raise ValueError(
                     'Must define the header schema globally or specifically in the task.'
